@@ -23,8 +23,8 @@ DEFAULT_DEFINITIONS = [
             {'field': 'STATE', 'type': 'VARCHAR'},
             {'field': 'YEAR', 'type': 'INT'},
             {'field': 'VISITLINK', 'type': 'BIGINT'},
-            {'field': 'ZIP', 'type': 'INT'},
-            {'field': 'ZIP3', 'type': 'INT'},
+            {'field': 'ZIP', 'type': 'VARCHAR'},
+            {'field': 'ZIP3', 'type': 'VARCHAR'},
             {'field': 'DAYSTOEVENT', 'type': 'INT'},
             {'field': 'RACE', 'type': 'INT'},
             {'field': 'FEMALE', 'type': 'INT'},
@@ -255,81 +255,81 @@ DEFAULT_DEFINITIONS = [
             {'field': 'pr23', 'type': 'VARCHAR'},
             {'field': 'pr24', 'type': 'VARCHAR'},
             {'field': 'pr25', 'type': 'VARCHAR'},
-            {'field': 'pryear1', 'type': 'VARCHAR'},
-            {'field': 'pryear2', 'type': 'VARCHAR'},
-            {'field': 'pryear3', 'type': 'VARCHAR'},
-            {'field': 'pryear4', 'type': 'VARCHAR'},
-            {'field': 'pryear5', 'type': 'VARCHAR'},
-            {'field': 'pryear6', 'type': 'VARCHAR'},
-            {'field': 'pryear7', 'type': 'VARCHAR'},
-            {'field': 'pryear8', 'type': 'VARCHAR'},
-            {'field': 'pryear9', 'type': 'VARCHAR'},
-            {'field': 'pryear10', 'type': 'VARCHAR'},
-            {'field': 'pryear11', 'type': 'VARCHAR'},
-            {'field': 'pryear12', 'type': 'VARCHAR'},
-            {'field': 'pryear13', 'type': 'VARCHAR'},
-            {'field': 'pryear14', 'type': 'VARCHAR'},
-            {'field': 'pryear15', 'type': 'VARCHAR'},
-            {'field': 'pryear16', 'type': 'VARCHAR'},
-            {'field': 'pryear17', 'type': 'VARCHAR'},
-            {'field': 'pryear18', 'type': 'VARCHAR'},
-            {'field': 'pryear19', 'type': 'VARCHAR'},
-            {'field': 'pryear20', 'type': 'VARCHAR'},
-            {'field': 'pryear21', 'type': 'VARCHAR'},
-            {'field': 'pryear22', 'type': 'VARCHAR'},
-            {'field': 'pryear23', 'type': 'VARCHAR'},
-            {'field': 'pryear24', 'type': 'VARCHAR'},
-            {'field': 'pryear25', 'type': 'VARCHAR'},
-            {'field': 'prmonth1', 'type': 'VARCHAR'},
-            {'field': 'prmonth2', 'type': 'VARCHAR'},
-            {'field': 'prmonth3', 'type': 'VARCHAR'},
-            {'field': 'prmonth4', 'type': 'VARCHAR'},
-            {'field': 'prmonth5', 'type': 'VARCHAR'},
-            {'field': 'prmonth6', 'type': 'VARCHAR'},
-            {'field': 'prmonth7', 'type': 'VARCHAR'},
-            {'field': 'prmonth8', 'type': 'VARCHAR'},
-            {'field': 'prmonth9', 'type': 'VARCHAR'},
-            {'field': 'prmonth10', 'type': 'VARCHAR'},
-            {'field': 'prmonth11', 'type': 'VARCHAR'},
-            {'field': 'prmonth12', 'type': 'VARCHAR'},
-            {'field': 'prmonth13', 'type': 'VARCHAR'},
-            {'field': 'prmonth14', 'type': 'VARCHAR'},
-            {'field': 'prmonth15', 'type': 'VARCHAR'},
-            {'field': 'prmonth16', 'type': 'VARCHAR'},
-            {'field': 'prmonth17', 'type': 'VARCHAR'},
-            {'field': 'prmonth18', 'type': 'VARCHAR'},
-            {'field': 'prmonth19', 'type': 'VARCHAR'},
-            {'field': 'prmonth20', 'type': 'VARCHAR'},
-            {'field': 'prmonth21', 'type': 'VARCHAR'},
-            {'field': 'prmonth22', 'type': 'VARCHAR'},
-            {'field': 'prmonth23', 'type': 'VARCHAR'},
-            {'field': 'prmonth24', 'type': 'VARCHAR'},
-            {'field': 'prmonth25', 'type': 'VARCHAR'},
-            {'field': 'prday1', 'type': 'VARCHAR'},
-            {'field': 'prday2', 'type': 'VARCHAR'},
-            {'field': 'prday3', 'type': 'VARCHAR'},
-            {'field': 'prday4', 'type': 'VARCHAR'},
-            {'field': 'prday5', 'type': 'VARCHAR'},
-            {'field': 'prday6', 'type': 'VARCHAR'},
-            {'field': 'prday7', 'type': 'VARCHAR'},
-            {'field': 'prday8', 'type': 'VARCHAR'},
-            {'field': 'prday9', 'type': 'VARCHAR'},
-            {'field': 'prday10', 'type': 'VARCHAR'},
-            {'field': 'prday11', 'type': 'VARCHAR'},
-            {'field': 'prday12', 'type': 'VARCHAR'},
-            {'field': 'prday13', 'type': 'VARCHAR'},
-            {'field': 'prday14', 'type': 'VARCHAR'},
-            {'field': 'prday15', 'type': 'VARCHAR'},
-            {'field': 'prday16', 'type': 'VARCHAR'},
-            {'field': 'prday17', 'type': 'VARCHAR'},
-            {'field': 'prday18', 'type': 'VARCHAR'},
-            {'field': 'prday19', 'type': 'VARCHAR'},
-            {'field': 'prday20', 'type': 'VARCHAR'},
-            {'field': 'prday21', 'type': 'VARCHAR'},
-            {'field': 'prday22', 'type': 'VARCHAR'},
-            {'field': 'prday23', 'type': 'VARCHAR'},
-            {'field': 'prday24', 'type': 'VARCHAR'},
-            {'field': 'prday25', 'type': 'VARCHAR'},
+            {'field': 'pryear1', 'type': 'INT'},
+            {'field': 'pryear2', 'type': 'INT'},
+            {'field': 'pryear3', 'type': 'INT'},
+            {'field': 'pryear4', 'type': 'INT'},
+            {'field': 'pryear5', 'type': 'INT'},
+            {'field': 'pryear6', 'type': 'INT'},
+            {'field': 'pryear7', 'type': 'INT'},
+            {'field': 'pryear8', 'type': 'INT'},
+            {'field': 'pryear9', 'type': 'INT'},
+            {'field': 'pryear10', 'type': 'INT'},
+            {'field': 'pryear11', 'type': 'INT'},
+            {'field': 'pryear12', 'type': 'INT'},
+            {'field': 'pryear13', 'type': 'INT'},
+            {'field': 'pryear14', 'type': 'INT'},
+            {'field': 'pryear15', 'type': 'INT'},
+            {'field': 'pryear16', 'type': 'INT'},
+            {'field': 'pryear17', 'type': 'INT'},
+            {'field': 'pryear18', 'type': 'INT'},
+            {'field': 'pryear19', 'type': 'INT'},
+            {'field': 'pryear20', 'type': 'INT'},
+            {'field': 'pryear21', 'type': 'INT'},
+            {'field': 'pryear22', 'type': 'INT'},
+            {'field': 'pryear23', 'type': 'INT'},
+            {'field': 'pryear24', 'type': 'INT'},
+            {'field': 'pryear25', 'type': 'INT'},
+            {'field': 'prmonth1', 'type': 'INT'},
+            {'field': 'prmonth2', 'type': 'INT'},
+            {'field': 'prmonth3', 'type': 'INT'},
+            {'field': 'prmonth4', 'type': 'INT'},
+            {'field': 'prmonth5', 'type': 'INT'},
+            {'field': 'prmonth6', 'type': 'INT'},
+            {'field': 'prmonth7', 'type': 'INT'},
+            {'field': 'prmonth8', 'type': 'INT'},
+            {'field': 'prmonth9', 'type': 'INT'},
+            {'field': 'prmonth10', 'type': 'INT'},
+            {'field': 'prmonth11', 'type': 'INT'},
+            {'field': 'prmonth12', 'type': 'INT'},
+            {'field': 'prmonth13', 'type': 'INT'},
+            {'field': 'prmonth14', 'type': 'INT'},
+            {'field': 'prmonth15', 'type': 'INT'},
+            {'field': 'prmonth16', 'type': 'INT'},
+            {'field': 'prmonth17', 'type': 'INT'},
+            {'field': 'prmonth18', 'type': 'INT'},
+            {'field': 'prmonth19', 'type': 'INT'},
+            {'field': 'prmonth20', 'type': 'INT'},
+            {'field': 'prmonth21', 'type': 'INT'},
+            {'field': 'prmonth22', 'type': 'INT'},
+            {'field': 'prmonth23', 'type': 'INT'},
+            {'field': 'prmonth24', 'type': 'INT'},
+            {'field': 'prmonth25', 'type': 'INT'},
+            {'field': 'prday1', 'type': 'INT'},
+            {'field': 'prday2', 'type': 'INT'},
+            {'field': 'prday3', 'type': 'INT'},
+            {'field': 'prday4', 'type': 'INT'},
+            {'field': 'prday5', 'type': 'INT'},
+            {'field': 'prday6', 'type': 'INT'},
+            {'field': 'prday7', 'type': 'INT'},
+            {'field': 'prday8', 'type': 'INT'},
+            {'field': 'prday9', 'type': 'INT'},
+            {'field': 'prday10', 'type': 'INT'},
+            {'field': 'prday11', 'type': 'INT'},
+            {'field': 'prday12', 'type': 'INT'},
+            {'field': 'prday13', 'type': 'INT'},
+            {'field': 'prday14', 'type': 'INT'},
+            {'field': 'prday15', 'type': 'INT'},
+            {'field': 'prday16', 'type': 'INT'},
+            {'field': 'prday17', 'type': 'INT'},
+            {'field': 'prday18', 'type': 'INT'},
+            {'field': 'prday19', 'type': 'INT'},
+            {'field': 'prday20', 'type': 'INT'},
+            {'field': 'prday21', 'type': 'INT'},
+            {'field': 'prday22', 'type': 'INT'},
+            {'field': 'prday23', 'type': 'INT'},
+            {'field': 'prday24', 'type': 'INT'},
+            {'field': 'prday25', 'type': 'INT'},
             {'field': 'prccs1', 'type': 'VARCHAR'},
             {'field': 'prccs2', 'type': 'VARCHAR'},
             {'field': 'prccs3', 'type': 'VARCHAR'},
@@ -543,9 +543,9 @@ DEFAULT_DEFINITIONS = [
             {'field': 'PR', 'type': 'VARCHAR'},
             {'field': 'PRCCS', 'type': 'VARCHAR'},
             {'field': 'PRDATE', 'type': 'VARCHAR'},
-            {'field': 'PRDAY', 'type': 'VARCHAR'},
-            {'field': 'PRMONTH', 'type': 'VARCHAR'},
-            {'field': 'PRYEAR', 'type': 'VARCHAR'},
+            {'field': 'PRDAY', 'type': 'INT'},
+            {'field': 'PRMONTH', 'type': 'INT'},
+            {'field': 'PRYEAR', 'type': 'INT'},
             {'field': 'PRV', 'type': 'VARCHAR'},
             {'field': 'PCLASS', 'type': 'VARCHAR'},
             {'field': 'PRMCCS', 'type': 'VARCHAR'},
