@@ -23,29 +23,11 @@ class Edition(models.Model):
     void = models.BooleanField(default=False)
     voided_at = models.DateTimeField(blank=True, null=True, default=None)
     
-    def generate_tables(self):
-        from djhcup_integration.utils import integrate_tables
-        integrations = [integrate_tables(d.pk, self.pk) for d in Definition.objects.all()]
-        """
-        EDITION_CATS = [
-            # a list of categories to include in each edition of an integration table set
-            dict(val='CORE_PROCESSED', long_entry=None, ds_abbr='CORE'),
-            dict(val='DX', long_entry='DX'),
-            dict(val='PR', long_entry='PR'),
-            dict(val='CHARGES', long_entry='CHGS'),
-            dict(val='UFLAGS', long_entry='UFLAGS'),
-        ]
-        
-        # for each category of data
-            # grab StagingTables with that category
-            # for each unique DataSource
-                # filter StagingTables down to those matching DataSource (within category)
-                
-        # need to somehow deal with extra columns--might just have to define integration/reporting field sets or something
-        create_sql = pyhcup.db.long_table_sql(db_table, str(source.abbreviation))
-        index_fields = ['KEY', 'VISITLINK', 'STATE', 'YEAR']
-        """
-        return integrations
+    def __unicode__(self):
+        return "<Edition {pk}>".format(pk=self.pk)
+    
+    def __repr__(self):
+        return self.__unicode__()
 
 
 class IntegrationTable(models.Model):
@@ -77,9 +59,6 @@ class IntegrationTable(models.Model):
     voided_at = models.DateTimeField(blank=True, null=True, default=None)
     records = models.IntegerField(blank=True, null=True, default=None)
     
-    def __unicode__(self):
-        return "IntegrationTable %d: %s" % (self.pk, self.name)
-    
     # overwrite to drop associated table by default when deleting
     def delete(self, drop_table=True, *args, **kwargs):
         if drop_table:
@@ -98,6 +77,23 @@ class IntegrationTable(models.Model):
         
         super(IntegrationTable, self).delete(*args, **kwargs)
     
+    
+    def __unicode__(self):
+        try:
+            d = self.definition.pk
+        except:
+            d = None
+        
+        try:
+            e = self.edition.pk
+        except:
+            e = None
+        
+        return "<IntegrationTable {pk}: {n}, definition={d} edition={e}>".format(pk=self.pk, n=self.name, d=d, e=e)
+    
+    def __repr__(self):
+        return self.__unicode__()
+    
     """
     def get_absolute_url(self):
         return reverse(
@@ -165,6 +161,9 @@ class Column(models.Model):
     Personally I believe this would be better if fields_in actually referred
     to djhcup_staging.models.Column objects, but then I'd need another layer
     that establishes the list of column names which qualify for inclusion.
+    Reason being that staging columns are not propagated as part of table
+    processing--they exist only as part of import loading.
+    
     
     Might still be good to do at a future date but right now is kind of a
     hassle.
@@ -173,7 +172,7 @@ class Column(models.Model):
     field_out = models.ForeignKey('ColumnName', related_name='field_out')
     TYPE_CHOICES = [
             ('INT', 'Integer'),
-            ('BIGINT', 'Integer'),
+            ('BIGINT', 'Very Large Integer'),
             ('TEXT', 'Text field'),
             ('VARCHAR', 'Character varying'),
             ('NUMERIC(2, 15)', 'Decimal, out to hundredths'),
@@ -182,6 +181,18 @@ class Column(models.Model):
     field_out_scale = models.IntegerField(blank=True, null=True, default=None)
     field_out_precision = models.IntegerField(blank=True, null=True, default=None)
     
+    def _is_numeric(self):
+        lower_type = self.field_out_data_type.lower()
+        if (lower_type in ['int', 'bigint'] or
+            'numeric' in lower_type):
+            return True
+        else:
+            return False
+    
+    def _name(self):
+        return self.field_out.value
+    name = property(_name)
+    
     def __unicode__(self):
         return '<Integration Column: {i} to {o} ({pk})>' \
             .format(i=[str(x.value) for x in self.fields_in.all()],
